.. riptable documentation master file, created by
   sphinx-quickstart on Sun Aug 30 14:42:04 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Riptable's documentation!
====================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:
   
   tutorial/tutorial



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
